@@ -5,7 +5,7 @@ use warnings;
 package Log::Any::Adapter::Stdout;
 
 # ABSTRACT: Simple adapter for logging to STDOUT
-our $VERSION = '1.705';
+our $VERSION = '1.707';
 
 use Log::Any::Adapter::Util ();
 
@@ -18,13 +18,13 @@ sub init {
     my ($self) = @_;
     if ( exists $self->{log_level} && $self->{log_level} =~ /\D/ ) {
         my $numeric_level = Log::Any::Adapter::Util::numeric_level( $self->{log_level} );
-        if ( !$numeric_level ) {
+        if ( !defined($numeric_level) ) {
             require Carp;
             Carp::carp( sprintf 'Invalid log level "%s". Defaulting to "%s"', $self->{log_level}, 'trace' );
         }
         $self->{log_level} = $numeric_level;
     }
-    if ( !$self->{log_level} ) {
+    if ( !defined $self->{log_level} ) {
         $self->{log_level} = $trace_level;
     }
 }
@@ -62,7 +62,7 @@ Log::Any::Adapter::Stdout - Simple adapter for logging to STDOUT
 
 =head1 VERSION
 
-version 1.705
+version 1.707
 
 =head1 SYNOPSIS
 
